"""Class-based context manager to redirect stdout.
"""

from __future__ import print_function

import sys


class Redirect(object):
    """Context manager.
    """

    def __init__(self, new_stdout):
        """Takes new stdout.
        """
        self.new_stdout = new_stdout

    def __enter__(self):
        """Redirect.
        """
        self.save_stdout = sys.stdout
        sys.stdout = self.new_stdout

    def __exit__(self, exception_type, exception_value, exception_traceback):
        """Re-redirect.
        """
        sys.stdout = self.save_stdout


def test():
    """Check if redirections works.

    The first print should go the file; the second
    to the screen.
    """
    with open('temp.txt', "w") as fobj:
        with Redirect(fobj):
            print("Hello world.")
    print('Back again.')

    with open('temp.txt', "a") as fobj, Redirect(fobj):
            print("Hello world, again.")
    print('Back again.')


if __name__ == '__main__':

    test()
