"""Context manager to redirect stdout with contextlib.
"""

from __future__ import print_function

from contextlib import contextmanager
import sys


@contextmanager
def stdout_redirected(new_stdout):
    """Redirect stdout.
    """
    save_stdout = sys.stdout
    sys.stdout = new_stdout
    try:
        yield
    finally:
        sys.stdout = save_stdout


def test():
    """Check if redirections works.

    The first print should go the file; the second
    to the screen.
    """
    with open('temp.txt', "w") as fobj:
        with stdout_redirected(fobj):
            print("Hello world")
    print('Back again.')


if __name__ == '__main__':

    test()
