"""Class-based context manager to change working directory.
"""

from __future__ import print_function

import os


class WorkDir(object):
    """Context manager to chage the current working directory.
    """

    def __init__(self, new_dir):
        """Takes new directory.
        """
        self.new_dir = new_dir

    def __enter__(self):
        """Go to new dir.
        """
        self.old_dir = os.getcwd()
        os.chdir(self.new_dir)

    def __exit__(self, exception_type, exception_value, exception_traceback):
        """Go back to original directory.
        """
        os.chdir(self.old_dir)


def test(work_dir):
    """Check if work dir is used temporally.

    """
    with WorkDir(work_dir):
        print('I am temporally here', os.getcwd())
    print('I am back here', os.getcwd())

if __name__ == '__main__':

    test('/tmp')  # make sure dir exists
