"""Context manager to change working directory.
"""

from __future__ import print_function

from contextlib import contextmanager
import os


@contextmanager
def work_dir(new_dir):
    """Change working directory.
    """
    old_dir = os.getcwd()
    os.chdir(new_dir)
    try:
        yield
    finally:
        os.chdir(old_dir)


def test(tmp_dir):
    """Check if work dir is used temporally.

    """
    with work_dir(tmp_dir):
        print('I am temporally here', os.getcwd())
    print ('I am back here', os.getcwd())


if __name__ == '__main__':

    test('/tmp')
