"""Decorator for measuring run times.

Paramterized version
"""

from __future__ import print_function

import functools
import time
import timeit

run_times = {}


def measure_time(run_times=run_times):
    """Decorator to measure function run times.
    """
    def _measure_time(func):
        """Function that takes the function that is to be wrapped.
        """
        @functools.wraps(func)
        def _proxy_func(*args, **kwargs):
            """Function that will replace the original function.
            """
            start = timeit.default_timer()
            res = func(*args, **kwargs)
            end = timeit.default_timer()
            key = '.'.join((func.__module__, func.__name__))
            run_times[key] = end - start
            return res
        return _proxy_func
    return _measure_time


# Use default dict to store measured times.
@measure_time()
def add(arg1, arg2):
    """Test function.
    """
    return arg1 + arg2

other_dict = {}
# Use other dict to store measured times.
@measure_time(run_times=other_dict)
def run_long():
    """Long running function.
    """
    time.sleep(1)


if __name__ == '__main__':
    add(10, 20)
    run_long()
    print(run_times)
    print(other_dict)